@@ -70,6 +70,14 @@ sub make_result {
     my $entity_class = shift;
     my %data = @_;
 
+    if ($entity_class->isa('Elive::Entity::User')
+	&& defined $data{loginPassword}) {
+	#
+	# return of passwrods is supressed
+	#
+	$data{loginPassword} = '';
+    }
+
     my ($adapter, $packed_data) = _pack_data($entity_class, \%data);
 
     my $self = bless {}, $class;
@@ -79,6 +87,15 @@ sub make_result {
     $self;
 }
 
+sub not_found {
+    my $class = shift;
+
+    my $self = bless {}, $class;
+    $self->result('');
+
+    $self;
+}
+
 ########################################################################
 package t::Elive::MockSOMFault;
 use warnings; use strict;
